@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2019-2021 The LumiSpy developers
+# Copyright 2019-2022 The LumiSpy developers
 #
 # This file is part of LumiSpy.
 #
 # LumiSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
+# the Free Software Foundation, either version 3 of the license, or
 # (at your option) any later version.
 #
 # LumiSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LumiSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 from .luminescence_spectrum import LumiSpectrum, LazyLumiSpectrum
 from .cl_spectrum import CLSpectrum, LazyCLSpectrum
@@ -23,8 +23,7 @@ from .cl_spectrum import CLSTEMSpectrum, LazyCLSTEMSpectrum
 from .pl_spectrum import PLSpectrum, LazyPLSpectrum
 from .el_spectrum import ELSpectrum, LazyELSpectrum
 from .luminescence_transient import LumiTransient, LazyLumiTransient
-from .cl_transient import CLTransient, LazyCLTransient
-from .pl_transient import PLTransient, LazyPLTransient
+from .luminescence_transientspec import LumiTransientSpectrum, LazyLumiTransientSpectrum
 
 
 __all__ = [
@@ -42,8 +41,6 @@ __all__ = [
     "LazyELSpectrum",
     "LumiTransient",
     "LazyLumiTransient",
-    "CLTransient",
-    "LazyCLTransient",
-    "PLTransient",
-    "LazyPLTransient",
+    "LumiTransientSpectrum",
+    "LazyLumiTransientSpectrum",
 ]
