@@ -1,22 +1,24 @@
 # -*- coding: utf-8 -*-
-# Copyright 2019-2021 The LumiSpy developers
+# Copyright 2019-2022 The LumiSpy developers
 #
 # This file is part of LumiSpy.
 #
 # LumiSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
+# the Free Software Foundation, either version 3 of the license, or
 # (at your option) any later version.
 #
 # LumiSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LumiSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
-"""Signal class for Cathodoluminescence spectral data.
+"""
+Signal class for cathodoluminescence spectral data
+--------------------------------------------------
 """
 
 from inspect import getfullargspec
@@ -30,19 +32,24 @@ from lumispy.signals import LumiSpectrum
 
 
 class CLSpectrum(LumiSpectrum):
-    """General 1D Cathodoluminescence signal class.
-    ----------
-    """
+    """**General 1D cathodoluminescence signal class.**"""
 
     _signal_type = "CL"
     _signal_dimension = 1
 
     def _make_signal_mask(self, luminescence_roi):
-        """
-        Creates a mask from the peak position and peak widths of the luminescence spectrum.
-        :param luminescence_roi: array
-            In the form of an array of pairwise elements [[peak1_x, peak1_width], [peak2_x, peak2_width],...].
-        :return: array
+        """Creates a mask from the peak position and peak widths of the
+        luminescence spectrum.
+
+        Parameters
+        ----------
+        luminescence_roi: array
+            In the form of an array of pairwise elements
+            [[peak1_x, peak1_width], [peak2_x, peak2_width],...].
+
+        Returns
+        -------
+        array
             A `signal_mask`.
         """
 
@@ -75,12 +82,6 @@ class CLSpectrum(LumiSpectrum):
         **kwargs
     ):
 
-        if not "threshold" in getfullargspec(self.spikes_removal_tool)[0]:
-            raise ImportError(
-                "Spike removal works only "
-                "if the non_uniform_axis branch of HyperSpy is used."
-            )
-
         if luminescence_roi is not None and signal_mask is not None:
             raise AttributeError(
                 "Only either `luminescence_roi` or the `signal_mask` can be an input."
@@ -117,31 +118,35 @@ class CLSpectrum(LumiSpectrum):
         else:
             return signal
 
-    REMOVE_SPIKES_DOCSTRINGS = """
-                Hyperspy-based spike removal tool adapted to Lumispy to run non-interactively and
-                without noise addition by default.
-                %s
-                show_diagnosis_histogram: bool
-                    Plot or not the derivative histogram to show the magnitude of the spikes present.
-                inplace: bool
-                    If False, a new signal object is created and returned. If True, the original signal object is modified.
-                luminescence_roi: array
-                    The peak position and peak widths of the peaks in the luminescence spectrum.
-                    In the form of an array of pairwise elements [[peak1_x, peak1_width], [peak2_x, peak2_width],...]
-                    in the units of the signal axis. It creates a signal_mask protecting the peak regions.
-                    To be used instead of `signal_mask`.
+    REMOVE_SPIKES_DOCSTRINGS = """HyperSpy-based spike removal tool adapted to
+        LumiSpy to run non-interactively and without noise addition by default.
+        %s
+        
+        Other Parameters
+        ----------------
+        show_diagnosis_histogram: bool
+            Plot or not the derivative histogram to show the magnitude of the spikes present.
+        inplace: bool
+            If False, a new signal object is created and returned. If True, the original signal object is modified.
+        luminescence_roi: array
+            The peak position and peak widths of the peaks in the luminescence spectrum.
+            In the form of an array of pairwise elements [[peak1_x, peak1_width], [peak2_x, peak2_width],...]
+            in the units of the signal axis. It creates a signal_mask protecting the peak regions.
+            To be used instead of `signal_mask`.
 
-                Returns
-                ----------
-                :return: None or CLSpectrum
-                    Depends on inplace, returns or overwrites the CLSpectrum after spike removal.
-                """
+        Returns
+        -------
+        None or CLSpectrum
+            Depends on inplace, returns or overwrites the CLSpectrum after spike removal.
+        """
     remove_spikes.__doc__ = REMOVE_SPIKES_DOCSTRINGS % (
         LumiSpectrum.spikes_removal_tool.__doc__
     )
 
 
 class LazyCLSpectrum(LazySignal, CLSpectrum):
+    """**General lazy 1D cathodoluminescence signal class.**"""
+
     _lazy = True
 
     pass
@@ -152,20 +157,27 @@ class LazyCLSpectrum(LazySignal, CLSpectrum):
 
 
 class CLSEMSpectrum(CLSpectrum):
+    """**1D scanning electron microscopy cathodoluminescence signal class.**"""
+
     _signal_type = "CL_SEM"
 
     def correct_grating_shift(
         self, cal_factor_x_axis, corr_factor_grating, sem_magnification, **kwargs
     ):
-        """ "
-        Applies shift caused by the grating offset wrt the scanning centre.
+        """Applies shift caused by the grating offset wrt the scanning centre.
         Authorship: Gunnar Kusch (gk419@cam.ac.uk)
 
-        :param cal_factor_x_axis: The navigation correction factor.
-        :param corr_factor_grating: The grating correction factor.
-        :param sem_magnification: The SEM (real) magnification value.
+        Parameters
+        ----------
+        cal_factor_x_axis
+            The navigation correction factor.
+        corr_factor_grating
+            The grating correction factor.
+        sem_magnification
+            The SEM (real) magnification value.
             For the Attolight original metadata, take the `SEM.Real_Magnification` value
-        :param kwargs: The parameters passed to `hyperspy.align1D()` function like:
+        kwargs
+            The parameters passed to `hyperspy.align1D()` function like:
             interpolation_method ('linear', 'nearest', 'zero', 'slinear', 'quadratic, 'cubic')
             parallel: Bool
             crop, expand, fill_value ...
@@ -197,6 +209,8 @@ class CLSEMSpectrum(CLSpectrum):
 
 
 class LazyCLSEMSpectrum(LazySignal, CLSEMSpectrum):
+    """**Lazy 1D scanning electron microscopy cathodoluminescence signal class.**"""
+
     _lazy = True
 
     pass
@@ -207,6 +221,7 @@ class LazyCLSEMSpectrum(LazySignal, CLSEMSpectrum):
 
 
 class CLSTEMSpectrum(CLSpectrum):
+    """**1D scanning transmission electron microscopy cathodoluminescence signal class.**"""
 
     _signal_type = "CL_STEM"
 
@@ -214,6 +229,7 @@ class CLSTEMSpectrum(CLSpectrum):
 
 
 class LazyCLSTEMSpectrum(LazySignal, CLSTEMSpectrum):
+    """**Lazy 1D scanning transmission electron microscopy cathodoluminescence signal class.**"""
 
     _lazy = True
 
