@@ -1,22 +1,24 @@
 # -*- coding: utf-8 -*-
-# Copyright 2019-2021 The LumiSpy developers
+# Copyright 2019-2022 The LumiSpy developers
 #
 # This file is part of LumiSpy.
 #
 # LumiSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
+# the Free Software Foundation, either version 3 of the license, or
 # (at your option) any later version.
 #
 # LumiSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LumiSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
-"""Signal class for Electroluminescence spectral data.
+"""
+Signal class for electroluminescence spectral data
+--------------------------------------------------
 """
 
 from hyperspy._signals.lazy import LazySignal
@@ -25,9 +27,7 @@ from lumispy.signals import LumiSpectrum
 
 
 class ELSpectrum(LumiSpectrum):
-    """General 1D Electroluminescence signal class.
-    ----------
-    """
+    """**General 1D electroluminescence signal class**"""
 
     _signal_type = "EL"
     _signal_dimension = 1
@@ -36,6 +36,8 @@ class ELSpectrum(LumiSpectrum):
 
 
 class LazyELSpectrum(LazySignal, ELSpectrum):
+    """**General lazy 1D electroluminescence signal class**"""
+
     _lazy = True
 
     pass
