@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2019-2021 The LumiSpy developers
+# Copyright 2019-2022 The LumiSpy developers
 #
 # This file is part of LumiSpy.
 #
 # LumiSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
+# the Free Software Foundation, either version 3 of the license, or
 # (at your option) any later version.
 #
 # LumiSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LumiSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 
 import pytest
 from numpy import arange
@@ -29,8 +29,7 @@ from lumispy.signals import (
     PLSpectrum,
     ELSpectrum,
     LumiTransient,
-    CLTransient,
-    PLTransient,
+    LumiTransientSpectrum,
     LazyLumiSpectrum,
     LazyCLSpectrum,
     LazyCLSEMSpectrum,
@@ -38,8 +37,7 @@ from lumispy.signals import (
     LazyPLSpectrum,
     LazyELSpectrum,
     LazyLumiTransient,
-    LazyCLTransient,
-    LazyPLTransient,
+    LazyLumiTransientSpectrum,
 )
 
 signal1d_class_list = [
@@ -55,14 +53,12 @@ signal1d_class_list = [
     LazyCLSTEMSpectrum,
     LazyPLSpectrum,
     LazyELSpectrum,
+    LumiTransient,
+    LazyLumiTransient,
 ]
 signal2d_class_list = [
-    LumiTransient,
-    CLTransient,
-    PLTransient,
-    LazyLumiTransient,
-    LazyCLTransient,
-    LazyPLTransient,
+    LumiTransientSpectrum,
+    LazyLumiTransientSpectrum,
 ]
 
 
