@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2019-2021 The LumiSpy developers
+# Copyright 2019-2022 The LumiSpy developers
 #
 # This file is part of LumiSpy.
 #
 # LumiSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
+# the Free Software Foundation, either version 3 of the license, or
 # (at your option) any later version.
 #
 # LumiSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with LumiSpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LumiSpy. If not, see <https://www.gnu.org/licenses/#GPL>.
 import warnings
 
 import numpy as np
@@ -35,7 +35,7 @@ from hyperspy.axes import *
 
 
 def _n_air(x):
-    """Refractive index of air as a function of WL in nm.
+    """Relative permittivity of air as a function of WL in nm.
     This analytical function is correct for the range 185-1700 nm.
     According to `E.R. Peck and K. Reeder. Dispersion of air,
     J. Opt. Soc. Am. 62, 958-962 (1972).`
@@ -61,8 +61,8 @@ def _n_air(x):
     return (
         1
         + 806051e-10
-        + 2480990e-8 / (132274e-3 - 1 / wl ** 2)
-        + 174557e-9 / (3932957e-5 - 1 / wl ** 2)
+        + 2480990e-8 / (132274e-3 - 1 / wl**2)
+        + 174557e-9 / (3932957e-5 - 1 / wl**2)
     )
 
 
@@ -86,12 +86,6 @@ def axis2eV(ax0):
     dependent permittivity of air. Assumes wavelength in units of nm unless the
     axis units are specifically set to µm.
     """
-    # Check if non_uniform_axis is available in hyperspy version
-    if not "axis" in getfullargspec(DataAxis)[0]:
-        raise ImportError(
-            "Conversion to energy axis works only "
-            "if the non_uniform_axis branch of HyperSpy is used."
-        )
     if ax0.units == "eV":
         raise AttributeError("Signal unit is already eV.")
     # transform axis, invert direction
@@ -107,8 +101,9 @@ def axis2eV(ax0):
 
 def data2eV(data, factor, ax0, evaxis):
     """The intensity is converted from counts/nm (counts/µm) to counts/meV by
-    doing a Jacobian transformation, see e.g. Wang and Townsend, J. Lumin. 142,
-    202 (2013). Ensures that integrated signals are still correct.
+    doing a Jacobian transformation, see e.g. Mooney and Kambhampati, J. Phys.
+    Chem. Lett. 4, 3316 (2013). Ensures that integrated signals are still
+    correct.
     """
     if ax0.units == "µm":
         return (
@@ -116,10 +111,27 @@ def data2eV(data, factor, ax0, evaxis):
             * factor
             * c.h
             * c.c
-            / (c.e * _n_air(1000 * ax0.axis)[::-1] * evaxis ** 2)
+            / (c.e * _n_air(1000 * ax0.axis)[::-1] * evaxis**2)
         )
     else:
-        return data * factor * c.h * c.c / (c.e * _n_air(ax0.axis[::-1]) * evaxis ** 2)
+        return data * factor * c.h * c.c / (c.e * _n_air(ax0.axis[::-1]) * evaxis**2)
+
+
+def var2eV(variance, factor, ax0, evaxis):
+    """The variance is converted doing a squared Jacobian renormalization to
+    match with the transformation of the data.
+    """
+    if ax0.units == "µm":
+        return (
+            variance
+            * (factor * c.h * c.c / (c.e * _n_air(1000 * ax0.axis)[::-1] * evaxis**2))
+            ** 2
+        )
+    else:
+        return (
+            variance
+            * (factor * c.h * c.c / (c.e * _n_air(ax0.axis[::-1]) * evaxis**2)) ** 2
+        )
 
 
 def nm2invcm(x):
@@ -136,13 +148,6 @@ def axis2invcm(ax0):
     r"""Converts given signal axis to wavenumber scale (cm$^{-1}$). Assumes
     wavelength in units of nm unless the axis units are specifically set to µm.
     """
-    # Check if non_uniform_axis is available in hyperspy version
-    if not "axis" in getfullargspec(DataAxis)[0]:
-        raise ImportError(
-            "Conversion to energy axis works only "
-            "if the non_uniform_axis branch of HyperSpy is used."
-        )
-
     if ax0.units == r"cm$^{-1}$":
         raise AttributeError(r"Signal unit is already cm$^{-1}$.")
     # transform axis, invert direction
@@ -158,13 +163,20 @@ def axis2invcm(ax0):
     return axis, factor
 
 
-def data2invcm(data, factor, ax0, invcmaxis):
+def data2invcm(data, factor, invcmaxis):
     r"""The intensity is converted from counts/nm (counts/µm) to
-    counts/cm$^{-1}$ by doing a Jacobian transformation, see e.g. Wang and
-    Townsend, J. Lumin. 142, 202 (2013). Ensures that integrated signals are
-    still correct.
+    counts/cm$^{-1}$ by doing a Jacobian transformation, see e.g. Mooney and
+    Kambhampati, J. Phys. Chem. Lett. 4, 3316 (2013). Ensures that integrated
+    signals are still correct.
     """
-    return data * factor / (invcmaxis ** 2)
+    return data * factor / (invcmaxis**2)
+
+
+def var2invcm(variance, factor, invcmaxis):
+    r"""The variance is converted doing a squared Jacobian renormalization to
+    match with the transformation of the data.
+    """
+    return variance * (factor / (invcmaxis**2)) ** 2
 
 
 #
@@ -301,6 +313,11 @@ def join_spectra(S, r=50, scale=True, average=False, kind="slinear"):
             )
             # join data vectors interpolating to a common uniform axis
             if average:  # average over range
+                if r == 1:
+                    raise ValueError(
+                        "Averaging can not be performed for r=1. "
+                        "Set average=False or r>1."
+                    )
                 ind2r = axis2.value2index(axis.axis[ind1 - r])
                 length = axis.axis[ind1 - r : ind1 + r].size
                 grad = 1 / (length - 1)
@@ -369,23 +386,22 @@ def join_spectra(S, r=50, scale=True, average=False, kind="slinear"):
     return S1
 
 
-GRATING_EQUATION_DOCSTRING_PARAMETERS = """
-        gamma_deg: float
-            Inclination angle between the focal plane and the centre of the grating
-            (found experimentally from calibration). In degree.
-        deviation_angle_deg: float
-            Also known as included angle. It is defined as the difference between
-            angle of diffraction ($\\beta$) and angle of incidence ($\\alpha$).
-            Given by manufacturer specsheet. In degree.
-        focal_length_mm: float
-            Given by manufacturer specsheet. In mm.
-        ccd_width_mm: float
-            The width of the CDD. Given by manufacturer specsheet. In mm.
-        grating_central_wavelength_nm: float
-            Wavelength at the centre of the grating, where exit slit is placed. In nm.
-        grating_density_gr_mm: int
-            Grating density in gratings per mm.
-    """
+GRATING_EQUATION_DOCSTRING_PARAMETERS = r"""
+    gamma_deg: float
+        Inclination angle between the focal plane and the centre of the grating
+        (found experimentally from calibration). In degree.
+    deviation_angle_deg: float
+        Also known as included angle. It is defined as the difference between
+        angle of diffraction (:math:`\beta`) and angle of incidence
+        (:math:`\alpha`). Given by manufacturer specsheet. In degree.
+    focal_length_mm: float
+        Given by manufacturer specsheet. In mm.
+    ccd_width_mm: float
+        The width of the CDD. Given by manufacturer specsheet. In mm.
+    grating_central_wavelength_nm: float
+        Wavelength at the centre of the grating, where exit slit is placed. In nm.
+    grating_density_gr_mm: int
+        Grating density in gratings per mm."""
 
 
 def solve_grating_equation(
@@ -397,18 +413,20 @@ def solve_grating_equation(
     grating_central_wavelength_nm,
     grating_density_gr_mm,
 ):
-    """
-    Solves the grating equation.
-    See `horiba.com/uk/scientific/products/optics-tutorial/wavelength-pixel-position` for equations.
-        Parameters
-        ----------
-        axis: hyperspy.axis
-            Axis in pixel units (no units) to convert to wavelength.
-        %s
+    r"""Solves the grating equation.
+    See `horiba.com/uk/scientific/products/optics-tutorial/wavelength-pixel-position`
+    for equations.
 
-        Returns
-        -------
-        axis: hyperspy.axis:
+    Parameters
+    ----------
+    axis: hyperspy.axis
+        Axis in pixel units (no units) to convert to wavelength.
+    %s
+
+    Returns
+    -------
+    axis: hyperspy.axis
+        HyperSpy axis object.
     """
 
     # From axis --> x-array
